@@ -18,7 +18,10 @@ import urllib3.exceptions
 
 from . import _private
 from . import commandline
+from . import conf as osc_conf
+from . import core as osc_core
 from . import oscerr
+from . import output
 from .OscConfigParser import configparser
 from .oscssl import CertVerificationError
 from .util.cpio import CpioError
@@ -35,6 +38,14 @@ except:
         pass
 
 
+try:
+    from keyring.errors import KeyringLocked
+except ImportError:
+    # python-keyring is not installed
+    class KeyringLocked(Exception):
+        pass
+
+
 # the good things are stolen from Matt Mackall's mercurial
 
 
@@ -52,19 +63,21 @@ for name in 'SIGBREAK', 'SIGHUP', 'SIGTERM':
 def run(prg, argv=None):
     try:
         try:
-            if '--debugger' in sys.argv:
+            # we haven't parsed options yet, that's why we rely on argv directly
+            if "--debugger" in (argv or sys.argv[1:]):
                 pdb.set_trace()
-            # here we actually run the program:
-            return prg.main(argv)
+            # here we actually run the program
+            prg.main(argv)
+            return 0
         except:
-            # look for an option in the prg.options object and in the config
-            # dict print stack trace, if desired
-            if getattr(prg.options, 'traceback', None) or getattr(prg.conf, 'config', {}).get('traceback', None) or \
-               getattr(prg.options, 'post_mortem', None) or getattr(prg.conf, 'config', {}).get('post_mortem', None):
+            # If any of these was set via the command-line options,
+            # the config values are expected to be changed accordingly.
+            # That's why we're working only with the config.
+            if osc_conf.config["traceback"] or osc_conf.config["post_mortem"]:
                 traceback.print_exc(file=sys.stderr)
                 # we could use http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/52215
             # enter the debugger, if desired
-            if getattr(prg.options, 'post_mortem', None) or getattr(prg.conf, 'config', {}).get('post_mortem', None):
+            if osc_conf.config["post_mortem"]:
                 if sys.stdout.isatty() and not hasattr(sys, 'ps1'):
                     pdb.post_mortem(sys.exc_info()[2])
                 else:
@@ -80,20 +93,12 @@ def run(prg, argv=None):
     except oscerr.APIError as e:
         print('BuildService API error:', e.msg, file=sys.stderr)
     except oscerr.LinkExpandError as e:
-        print('Link "%s/%s" cannot be expanded:\n' % (e.prj, e.pac), e.msg, file=sys.stderr)
+        print(f'Link "{e.prj}/{e.pac}" cannot be expanded:\n', e.msg, file=sys.stderr)
         print('Use "osc repairlink" to fix merge conflicts.\n', file=sys.stderr)
     except oscerr.WorkingCopyWrongVersion as e:
         print(e, file=sys.stderr)
     except oscerr.NoWorkingCopy as e:
         print(e, file=sys.stderr)
-        if os.path.isdir('.git'):
-            print("Current directory looks like git.", file=sys.stderr)
-        if os.path.isdir('.hg'):
-            print("Current directory looks like mercurial.", file=sys.stderr)
-        if os.path.isdir('.svn'):
-            print("Current directory looks like svn.", file=sys.stderr)
-        if os.path.isdir('CVS'):
-            print("Current directory looks like cvs.", file=sys.stderr)
     except HTTPError as e:
         print('Server returned an error:', e, file=sys.stderr)
         if hasattr(e, 'osc_msg'):
@@ -104,23 +109,21 @@ def run(prg, argv=None):
         except AttributeError:
             body = ''
 
-        if getattr(prg.options, 'debug', None) or \
-           getattr(prg.conf, 'config', {}).get('debug', None):
-            print(e.hdrs, file=sys.stderr)
-            print(body, file=sys.stderr)
+        output.print_msg(e.hdrs, print_to="debug")
+        output.print_msg(body, print_to="debug")
 
         if e.code in [400, 403, 404, 500]:
             if b'<summary>' in body:
                 msg = body.split(b'<summary>')[1]
                 msg = msg.split(b'</summary>')[0]
-                msg = _private.api.xml_escape(msg)
+                msg = _private.api.xml_unescape(msg)
                 print(decode_it(msg), file=sys.stderr)
         if e.code >= 500 and e.code <= 599:
-            print('\nRequest: %s' % e.filename)
+            print(f'\nRequest: {e.filename}')
             print('Headers:')
             for h, v in e.hdrs.items():
                 if h != 'Set-Cookie':
-                    print("%s: %s" % (h, v))
+                    print(f"{h}: {v}")
 
     except BadStatusLine as e:
         print('Server returned an invalid response:', e, file=sys.stderr)
@@ -130,7 +133,7 @@ def run(prg, argv=None):
     except URLError as e:
         msg = 'Failed to reach a server'
         if hasattr(e, '_osc_host_port'):
-            msg += ' (%s)' % e._osc_host_port
+            msg += f' ({e._osc_host_port})'
         msg += ':\n'
         print(msg, e.reason, file=sys.stderr)
     except ssl.SSLError as e:
@@ -151,14 +154,12 @@ def run(prg, argv=None):
         print(e.message, file=sys.stderr)
     except oscerr.OscIOError as e:
         print(e.msg, file=sys.stderr)
-        if getattr(prg.options, 'debug', None) or \
-           getattr(prg.conf, 'config', {}).get('debug', None):
-            print(e.e, file=sys.stderr)
+        output.print_msg(e.e, print_to="debug")
     except (oscerr.WrongOptions, oscerr.WrongArgs) as e:
         print(e, file=sys.stderr)
         return 2
     except oscerr.ExtRuntimeError as e:
-        print(e.file + ':', e.msg, file=sys.stderr)
+        print(f"{e.file}:", e.msg, file=sys.stderr)
     except oscerr.ServiceRuntimeError as e:
         print(e.msg, file=sys.stderr)
     except oscerr.WorkingCopyOutdated as e:
@@ -172,19 +173,28 @@ def run(prg, argv=None):
         print(e.msg, file=sys.stderr)
         traceback.print_exc(file=sys.stderr)
     except oscerr.PackageError as e:
-        print(e.msg, file=sys.stderr)
+        print(str(e), file=sys.stderr)
     except PackageError as e:
-        print('%s:' % e.fname, e.msg, file=sys.stderr)
+        print(f'{e.fname}:', e.msg, file=sys.stderr)
     except RPMError as e:
         print(e, file=sys.stderr)
+    except KeyringLocked as e:
+        print(e, file=sys.stderr)
     except CertVerificationError as e:
         print(e, file=sys.stderr)
     except urllib3.exceptions.MaxRetryError as e:
         print(e.reason, file=sys.stderr)
+    except urllib3.exceptions.ProtocolError as e:
+        print(e.args[0], file=sys.stderr)
     except CpioError as e:
         print(e, file=sys.stderr)
     except oscerr.OscBaseError as e:
         print('*** Error:', e, file=sys.stderr)
+    if osc_core.MESSAGE_BACKUPS:
+        print()
+        print("If you lost any edited commit messages due to an error, you may find them here:")
+        for path in osc_core.MESSAGE_BACKUPS:
+            print(f"  - {path}")
     return 1
 
 
@@ -207,6 +217,13 @@ def main():
         sys.stdout = os.fdopen(sys.stdout.fileno(), sys.stdout.mode, 1)
         sys.stderr = os.fdopen(sys.stderr.fileno(), sys.stderr.mode, 1)
 
-    sys.exit(run(commandline.Osc()))
+    appimage = os.getenv("APPIMAGE", None)
+    owd = os.getenv("OWD", None)
+    if appimage and owd:
+        # OWD stands for Original Working Directory and we need to switch there when running in an AppImage
+        # https://docs.appimage.org/packaging-guide/environment-variables.html
+        os.chdir(owd)
+
+    sys.exit(run(commandline.OscMainCommand()))
 
 # vim: sw=4 et
