@@ -1,4 +1,5 @@
 import argparse
+import glob
 import os
 import subprocess
 import sys
@@ -56,14 +57,26 @@ class GitObsCommand(osc.commandline_common.Command):
     def gitea_conf(self):
         return self.main_command.gitea_conf
 
+    @gitea_conf.setter
+    def gitea_conf(self, value):
+        self.main_command.gitea_conf = value
+
     @property
     def gitea_login(self):
         return self.main_command.gitea_login
 
+    @gitea_login.setter
+    def gitea_login(self, value):
+        self.main_command.gitea_login = value
+
     @property
     def gitea_conn(self):
         return self.main_command.gitea_conn
 
+    @gitea_conn.setter
+    def gitea_conn(self, value):
+        self.main_command.gitea_conn = value
+
     def print_gitea_settings(self):
         print(f"Using the following Gitea settings:", file=sys.stderr)
         print(f" * Config path: {self.gitea_conf.path}", file=sys.stderr)
@@ -73,7 +86,7 @@ class GitObsCommand(osc.commandline_common.Command):
         print("", file=sys.stderr)
 
     def add_argument_owner_repo(self, **kwargs):
-        self.add_argument(
+        return self.add_argument(
             "owner_repo",
             action=OwnerRepoAction,
             help="Owner and repo: (format: <owner>/<repo>)",
@@ -81,7 +94,7 @@ class GitObsCommand(osc.commandline_common.Command):
         )
 
     def add_argument_owner_repo_pull(self, **kwargs):
-        self.add_argument(
+        return self.add_argument(
             "owner_repo_pull",
             action=OwnerRepoPullAction,
             help="Owner, repo and pull request number (format: <owner>/<repo>#<pull-request-number>)",
@@ -89,13 +102,66 @@ class GitObsCommand(osc.commandline_common.Command):
         )
 
     def add_argument_new_repo_name(self):
-        self.add_argument(
+        return self.add_argument(
             "--new-repo-name",
             help="Name of the newly forked repo",
         )
 
 
+def complete_login(prefix, parsed_args, **kwargs):
+    from . import gitea_api
+
+    conf = getattr(parsed_args, "gitea_config", None)
+    gitea_conf = gitea_api.Config(conf)
+    return [i.name for i in gitea_conf.list_logins()]
+
+
+def complete_ssh_key_path(prefix, parsed_args, **kwargs):
+    return glob.glob(os.path.expanduser("~/.ssh/*.pub"))
+
+
+def complete_pr(prefix, parsed_args, **kwargs):
+    from . import gitea_api
+
+    conf = getattr(parsed_args, "gitea_config", None)
+    login = getattr(parsed_args, "gitea_login", None)
+    gitea_conf = gitea_api.Config(conf)
+    gitea_login = gitea_conf.get_login(name=login)
+    gitea_conn = gitea_api.Connection(gitea_login)
+    data = gitea_api.PullRequest.search(
+        gitea_conn,
+        state="open",
+    ).json()
+    data.sort(key=gitea_api.PullRequest.cmp)
+    return [f"{entry['repository']['full_name']}#{entry['number']}" for entry in data]
+
+
+def complete_checkout_pr(prefix, parsed_args, **kwargs):
+    from . import gitea_api
+
+    git = gitea_api.Git(".")
+    owner, repo = git.get_owner_repo()
+
+    conf = getattr(parsed_args, "gitea_config", None)
+    login = getattr(parsed_args, "gitea_login", None)
+    gitea_conf = gitea_api.Config(conf)
+    gitea_login = gitea_conf.get_login(name=login)
+    gitea_conn = gitea_api.Connection(gitea_login)
+    data = gitea_api.PullRequest.list(
+        gitea_conn,
+        owner=owner,
+        repo=repo,
+        state="open",
+    ).json()
+    data.sort(key=gitea_api.PullRequest.cmp)
+    return [f"{entry['number']}" for entry in data]
+
+
 class GitObsMainCommand(osc.commandline_common.MainCommand):
+    """
+    git-obs is a command-line client for interacting with Git repositories within a Gitea instance that is part of an Open Build Service (OBS).
+    """
+
     name = "git-obs"
 
     MODULES = (
@@ -119,7 +185,7 @@ class GitObsMainCommand(osc.commandline_common.MainCommand):
             "-G",
             "--gitea-login",
             help="Name of the login entry in the config file. Default: $GIT_OBS_LOGIN or the default entry from the config file.",
-        )
+        ).completer = complete_login
 
     def post_parse_args(self, args):
         if not args.gitea_config:
@@ -136,12 +202,16 @@ class GitObsMainCommand(osc.commandline_common.MainCommand):
 
 
     @classmethod
-    def main(cls, argv=None, run=True):
+    def main(cls, argv=None, run=True, argparse_manpage=False):
         """
         Initialize OscMainCommand, load all commands and run the selected command.
         """
         cmd = cls()
+        # argparse-manpage splits command's help text to help and description
+        # we normally use both in the --help output, but want to change that for argparse-manpage
+        cmd.argparse_manpage = argparse_manpage
         cmd.load_commands()
+        cmd.enable_autocomplete()
         if run:
             args = cmd.parse_args(args=argv)
             exit_code = cmd.run(args)
@@ -158,12 +228,20 @@ class GitObsMainCommand(osc.commandline_common.MainCommand):
             self._gitea_conf = gitea_api.Config(self._args.gitea_config)
         return self._gitea_conf
 
+    @gitea_conf.setter
+    def gitea_conf(self, value):
+        self._gitea_conf = value
+
     @property
     def gitea_login(self):
         if self._gitea_login is None:
             self._gitea_login = self.gitea_conf.get_login(name=self._args.gitea_login)
         return self._gitea_login
 
+    @gitea_login.setter
+    def gitea_login(self, value):
+        self._gitea_login = value
+
     @property
     def gitea_conn(self):
         from . import gitea_api
@@ -173,10 +251,25 @@ class GitObsMainCommand(osc.commandline_common.MainCommand):
             assert self._gitea_login is not None
         return self._gitea_conn
 
+    @gitea_conn.setter
+    def gitea_conn(self, value):
+        self._gitea_conn = value
+
+
+def argparse_manpage_get_parser():
+    """
+    Needed by argparse-manpage to generate man pages from the argument parser.
+    """
+    main, _ = GitObsMainCommand.main(run=False, argparse_manpage=True)
+    return main.parser
+
 
 def main():
     try:
         GitObsMainCommand.main()
+    except KeyboardInterrupt:
+        print_msg("Interrupted on user request", print_to="error")
+        sys.exit(1)
     except oscerr.OscBaseError as e:
         print_msg(str(e), print_to="error")
         sys.exit(1)
