@@ -1,3 +1,4 @@
+import getpass
 import sys
 
 import osc.commandline_git
@@ -12,12 +13,14 @@ class LoginUpdateCommand(osc.commandline_git.GitObsCommand):
     parent = "LoginCommand"
 
     def init_arguments(self):
+        from osc.commandline_git import complete_ssh_key_path
+
         self.parser.add_argument("name")
         self.parser.add_argument("--new-name")
         self.parser.add_argument("--new-url")
         self.parser.add_argument("--new-user")
-        self.parser.add_argument("--new-token")
-        self.parser.add_argument("--new-ssh-key")
+        self.parser.add_argument("--new-token", help="Set to '-' to invoke a secure interactive prompt.")
+        self.parser.add_argument("--new-ssh-key").completer = complete_ssh_key_path
         self.parser.add_argument("--set-as-default", action="store_true")
 
     def run(self, args):
@@ -31,6 +34,11 @@ class LoginUpdateCommand(osc.commandline_git.GitObsCommand):
         print("Original entry:")
         print(original_login.to_human_readable_string())
 
+        if args.new_token == "-":
+            print(file=sys.stderr)
+            while not args.new_token or args.new_token == "-":
+                args.new_token = getpass.getpass(prompt=f"Enter a new Gitea token for user '{args.new_user or original_login.user}': ")
+
         updated_login = self.gitea_conf.update_login(
             args.name,
             new_name=args.new_name,
