@@ -18,7 +18,7 @@ class Repo:
         match = re.match(r"^([^/]+)/([^/]+)$", repo_id)
         if not match:
             raise ValueError(f"Invalid repo id: {repo_id}")
-        return match.groups()
+        return match.group(1), match.group(2)
 
     @classmethod
     def get(
@@ -44,6 +44,8 @@ class Repo:
         owner: str,
         repo: str,
         *,
+        branch: Optional[str] = None,
+        quiet: bool = False,
         directory: Optional[str] = None,
         cwd: Optional[str] = None,
         anonymous: bool = False,
@@ -78,7 +80,8 @@ class Repo:
             if repo_data["owner"]["login"] == user["login"]:
                 # we're cloning our own repo, setting remote to the parent (if exists)
                 parent = repo_data["parent"]
-                remotes["parent"] = parent["clone_url"] if anonymous else parent["ssh_url"]
+                if parent:
+                    remotes["parent"] = parent["clone_url"] if anonymous else parent["ssh_url"]
             else:
                 # we're cloning someone else's repo, setting remote to our fork (if exists)
                 from . import Fork
@@ -111,6 +114,13 @@ class Repo:
 
         # clone
         cmd = ["git", "clone", clone_url, directory]
+
+        if branch:
+            cmd += ["--branch", branch]
+
+        if quiet:
+            cmd += ["--quiet"]
+
         subprocess.run(cmd, cwd=cwd, env=env, check=True)
 
         # setup remotes
