@@ -172,9 +172,11 @@ class Store:
         self.write_string(fn, value, subdir=subdir)
 
     def read_xml_node(self, fn, node_name, subdir=None):
+        from ..util.xml import xml_parse
+
         path = self.get_path(fn, subdir=subdir)
         try:
-            tree = ET.parse(path)
+            tree = xml_parse(path)
         except SyntaxError as e:
             msg = f"Unable to parse '{path}': {e}"
             raise oscerr.NoWorkingCopy(msg)
@@ -405,7 +407,13 @@ def check_store_version(dir):
         if v == "1.0":
             store_dir = os.path.join(dir, store)
             sources_dir = os.path.join(dir, store, "sources")
-            os.makedirs(sources_dir, exist_ok=True)
+            sources_dir_mv = sources_dir
+
+            if os.path.isfile(sources_dir):
+                # there is a conflict with an existing "sources" file
+                sources_dir_mv = os.path.join(dir, store, "_sources")
+
+            os.makedirs(sources_dir_mv, exist_ok=True)
 
             s = Store(dir, check=False)
             if s.is_package and not s.scmurl:
@@ -416,7 +424,7 @@ def check_store_version(dir):
 
                 for fn in os.listdir(store_dir):
                     old_path = os.path.join(store_dir, fn)
-                    new_path = os.path.join(sources_dir, fn)
+                    new_path = os.path.join(sources_dir_mv, fn)
                     if not os.path.isfile(old_path):
                         continue
                     if fn in Package.REQ_STOREFILES or fn in Package.OPT_STOREFILES:
@@ -426,6 +434,9 @@ def check_store_version(dir):
                     if os.path.isfile(old_path):
                         os.rename(old_path, new_path)
 
+            if sources_dir != sources_dir_mv:
+                os.rename(sources_dir_mv, sources_dir)
+
             v = "2.0"
             s.write_string("_osclib_version", v)
             migrated = True
@@ -454,6 +465,8 @@ def is_package_dir(d):
 
 
 def read_filemeta(dir):
+    from ..util.xml import xml_parse
+
     global store
 
     msg = f'\'{dir}\' is not a valid working copy.'
@@ -466,7 +479,7 @@ def read_filemeta(dir):
         raise oscerr.NoWorkingCopy(f'{msg} ({filesmeta} does not exist)')
 
     try:
-        r = ET.parse(filesmeta)
+        r = xml_parse(filesmeta)
     except SyntaxError as e:
         raise oscerr.NoWorkingCopy(f'{msg}\nWhen parsing .osc/_files, the following error was encountered:\n{e}')
     return r
